---
title: <span class="badge object-type-scalar"></span> EventsPerMinute
---
# <span class="badge object-type-scalar"></span> EventsPerMinute

Throughput: events/min (epm)

## Definition

```python
# Throughput: events/min (epm)
EventsPerMinute: typing.Literal["epm"] = "epm"
```
